<?php

require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-terms-popup-on-user-login-keyhandler.php';

class Terms_Popup_On_User_Login_Admin_Settings {
    
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
    private $version;
    
    /**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      array    $tpul_settings_term_modal_options    The settings for the modal.
	 */    
    private $tpul_settings_general_options;
    
    /**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      array    $tpul_settings_term_modal_options    The settings for the modal.
	 */    
    private $tpul_settings_term_modal_options;


    private $license_key_handler;
   

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->license_key_handler = new Terms_Popup_On_User_Login_Key_Handler($this->plugin_name, $this->version);

    }
    
    /**
	 * This function introduces the theme options into the 'Settings' menu and into a top-level
	 * 'Perfecto Portfolio' menu.
	 */
	public function setup_plugin_options_menu() {
        add_submenu_page(
            'options-general.php',
			'Terms Popup On User Login Settings', 					// The title to be displayed in the browser window for this page.
			'Terms Popup On User Login',					        // The text to be displayed for this menu item
            'manage_options',					            // Which type of users can see this menu item
            'terms_popup_on_user_login_options',			        // The unique ID - that is, the slug - for this menu item
			array( $this, 'render_settings_page_content')	// The name of the function to call when rendering this menu's page
		);
    }

    /**---------------------------------------------------------------------
     * Default Options
     ---------------------------------------------------------------------*/

    public function default_general_options() {
		$defaults = array(
            'modal_to_show'	   =>	'',
            'tplu_license_key'	   =>	'',
            'tplu_license_key_valid_until'	   =>	'',
            'tplu_license_key_last_checked'	   =>	'',
		);
		return $defaults;
    }
    
    public function default_terms_modal_options() {
		$defaults = array(
			'terms_modal_pageid'	       =>	'',
			'terms_modal_title'	           =>	'Terms and Conditions',
			'terms_modal_subtitle'	       =>	'You must read and scroll down to accept it.',
			'terms_modal_logout_text'	   =>	'You are being Logged out..',
			'terms_modal_agreed_text'	   =>	'You have agreed to terms.',
			'terms_modal_accept_button'	   =>	'Accept',
            'terms_modal_decline_button'   =>	'Decline and Log Out',
            'terms_modal_accept_redirect'  =>	'',
			'terms_modal_decline_redirect' =>	'/',
			'terms_modal_disable_for_new' =>	0,
		);
		return $defaults;
	}


    /**---------------------------------------------------------------------
     * Settings fields for General Options
     ---------------------------------------------------------------------*/
    
	/**
	 * Initializes the theme's activated options
	 *
	 * This function is registered with the 'admin_init' hook.
	 */
	public function initialize_general_options(  ) {         

        if( false == get_option( 'tpul_settings_general_options' ) ) {
			$default_array = $this->default_general_options();
			update_option( 'tpul_settings_general_options', $default_array );
        }


        /**
         * Add Section
         */
        add_settings_section(
            'tpul_general_section', 
            __( 'General Settings for First', 'terms-popup-on-user-login' ), 
            array( $this, 'general_options_callback'),
            'tpul_settings_general_options'
        );

        /**
         * Add option to Section
         */

        add_settings_field( 
            'modal_to_show', 
            __( 'Terms Popup On User Login', 'terms-popup-on-user-login' ), 
            array( $this, 'dropdown_select_field_render'),
            'tpul_settings_general_options', 
            'tpul_general_section' 
        );

        // add_settings_field( 
        //     'tpul_terms_modal_demo', 
        //     __( 'Demo Terms Popup', 'terms-popup-on-user-login' ), 
        //     array( $this, 'demo_terms_modal_render'),
        //     'tpul_settings_general_options', 
        //     'tpul_general_section' 
        // );

        add_settings_field( 
            'tplu_license_key', 
            __( 'Enter License Key', 'terms-popup-on-user-login' ), 
            array( $this, 'tplu_license_key_render'),
            'tpul_settings_general_options', 
            'tpul_general_section' 
        );

        /**
         * Register Section
         */
        register_setting(
			'tpul_settings_general_options',
			'tpul_settings_general_options',
			array( $this, 'validate_general_options')
        );

    }

    /**
     * The Callback to assist with extra text
     */
    public function general_options_callback() {
		// echo '<p>' . esc_html__( '', 'terms-popup-on-user-login' ) . '</p>';
    }    

    /**
     * Validator Callback to assist in validation
     */
    public function validate_general_options( $input ) {

		// Create our array for storing the validated options
		$output = array();

		// Loop through each of the incoming options
		foreach( $input as $key => $value ) {
			// Check to see if the current option has a value. If so, process it.
			if( isset( $input[$key] ) ) {
				// Strip all HTML and PHP tags and properly handle quoted strings
				$output[$key] = strip_tags( stripslashes( $input[ $key ] ) );
			} // end if
		} // end foreach

		// Return the array processing any additional functions filtered by this action
		return apply_filters( 'validate_general_options', $output, $input );
    }    

    /**---------------------------------------------------------------------
     * Settings fields for Terms Popup
     ---------------------------------------------------------------------*/

    /**
	 * Initializes the theme's activated options
	 *
	 * This function is registered with the 'admin_init' hook.
	 */
    public function initialize_terms_modal_options( ){

        // delete_option('tpul_settings_term_modal_options');

        if( false == get_option( 'tpul_settings_term_modal_options' ) ) {
			$default_array = $this->default_terms_modal_options();
			update_option( 'tpul_settings_term_modal_options', $default_array );
        } 
        
        /**
         * Add Section
         */
        add_settings_section(
            'tpul_term_modal_section', 
            __( 'Terms Popup Settings', 'terms-popup-on-user-login' ), 
            array( $this, 'term_modal_options_callback'),
            'tpul_settings_term_modal_options'
        );
        
        /**
         * Add option to Section
         */        

        add_settings_field( 
            'terms_modal_title', 
            __( 'Popup title', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_title_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field( 
            'terms_modal_subtitle', 
            __( 'Subtitle', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_subtitle_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field( 
            'terms_modal_accept_button', 
            __( 'Accept button label', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_accept_button_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field( 
            'terms_modal_accept_redirect', 
            __( 'Accept redirect URL', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_accept_redirect_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field( 
            'terms_modal_decline_button', 
            __( 'Decline button label', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_decline_button_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field(
            'terms_modal_decline_redirect', 
            __( 'Decline redirect URL', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_decline_redirect_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );
        
        add_settings_field( 
            'terms_modal_agreed_text', 
            __( 'Accept confirmation text', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_agreed_text_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field( 
            'terms_modal_logout_text', 
            __( 'Decline and Logout confirmation text', 'terms-popup-on-user-login' ), 
            array( $this, 'terms_modal_logout_text_render'),
            'tpul_settings_term_modal_options', 
            'tpul_term_modal_section' 
        );

        add_settings_field(
            'terms_modal_content',
            __( 'Content to show as terms in Popup', 'terms-popup-on-user-login' ),
            array( $this, 'terms_modal_content_render'),
            'tpul_settings_term_modal_options',
            'tpul_term_modal_section'
        );

        add_settings_field(
            'terms_modal_pageid',
            __( 'Show your own page in terms in Popup', 'terms-popup-on-user-login' ),
            array( $this, 'dropdown_select_field_pages_render'),
            'tpul_settings_term_modal_options',
            'tpul_term_modal_section'
        );

        // add_settings_field( 
        //     'terms_modal_disable_for_new', 
        //     __( 'Disable This Modal for New Users', 'terms-popup-on-user-login' ), 
        //     array( $this, 'terms_modal_disable_for_new_render'),
        //     'tpul_settings_term_modal_options', 
        //     'tpul_term_modal_section' 
        // );

        /**
         * Register Section
         */
        register_setting(
			'tpul_settings_term_modal_options',
			'tpul_settings_term_modal_options',
			array( $this, 'validate_term_modal_options')
        );
    }

        /**
     * The Callback to assist with extra text
     */
    public function term_modal_options_callback() {
		echo '<p>' . __( 'Terms and conditions popup that will not dismiss until user clicks <b>Accept</b> or <b>Decline</b> button. <br/>You can redirect the user after either of the button clicks. User will be signed out after in case he clicked the Decline button. ', 'terms-popup-on-user-login' ) . '</p>';
    }


    /**
     * Validator Callback to assist in validation
     */
    public function validate_term_modal_options( $input ) {

		// Create our array for storing the validated options
		$output = array();

		// Loop through each of the incoming options
		foreach( $input as $key => $value ) {
			// Check to see if the current option has a value. If so, process it.
			if( isset( $input[$key] ) ) {
				// Strip all HTML and PHP tags and properly handle quoted strings
				$output[$key] = strip_tags( stripslashes( $input[ $key ] ) );
			} // end if
		} // end foreach

		// Return the array processing any additional functions filtered by this action
		return apply_filters( 'validate_term_modal_options', $output, $input );
    }    


    /**---------------------------------------------------------------------
     * Settings fields for Reset Users
     ---------------------------------------------------------------------*/

    /**
	 * Initializes the theme's activated options
	 *
	 * This function is registered with the 'admin_init' hook.
	 */
    public function initialize_reset_users_options( ){
         /**
         * Add Section
         */
        add_settings_section(
            'tpul_reset_users_section', 
            __( 'Advanced options', 'terms-popup-on-user-login' ), 
            array( $this, 'reset_users_options_callback'),
            'tpul_settings_reset_users_options'
        );
    }

        /**
     * The Callback to assist with extra text
     */
    public function reset_users_options_callback() {
		// echo '<p>' . __( '<b style="color: red;">WARNING! This can not be undone. Running the reset will make the popup show for every user again.</b>', 'terms-popup-on-user-login' ) . '</p>';
		// echo '<p>' . __( 'Advanced options', 'terms-popup-on-user-login' ) . '</p>';
    }

    /**---------------------------------------------------------------------
     * Render the actual page
     ---------------------------------------------------------------------*/
    
    /**
	 * Renders a simple page to display for the theme menu defined above.
	 */
	public function render_settings_page_content( $active_tab = '' ) {

        $this->tpul_settings_term_modal_options = get_option( 'tpul_settings_term_modal_options' ); 
        $this->tpul_settings_general_options = get_option( 'tpul_settings_general_options' );         

        ?>
        <!-- Create a header in the default WordPress 'wrap' container -->
		<div class="wrap">

            <h2><?php esc_html_e( 'Terms Popup On User Login Options', 'terms_popup_on_user_login' ); ?></h2>

            <?php settings_errors(); ?>


            <?php if( isset( $_GET[ 'tab' ] ) ) {
				$active_tab = $_GET[ 'tab' ];
			} else if( $active_tab == 'terms_modal_options' ) {
                $active_tab = 'terms_modal_options';
            } else if( $active_tab == 'reset_users_options' ) {
				$active_tab = 'reset_users_options';
			} else {
				$active_tab = 'general_options';
			} 

            ?>

            <h2 class="nav-tab-wrapper">
				<a href="?page=terms_popup_on_user_login_options&tab=general_options" class="nav-tab <?php echo $active_tab == 'general_options' ? 'nav-tab-active' : ''; ?>"><?php esc_html_e( 'General Settings', 'terms-popup-on-user-login' ); ?></a>
				<a href="?page=terms_popup_on_user_login_options&tab=terms_modal_options" class="nav-tab <?php echo $active_tab == 'terms_modal_options' ? 'nav-tab-active' : ''; ?>"><?php esc_html_e( 'Terms Popup', 'terms-popup-on-user-login' ); ?></a>
				<a href="?page=terms_popup_on_user_login_options&tab=reset_users_options" class="nav-tab <?php echo $active_tab == 'reset_users_options' ? 'nav-tab-active' : ''; ?>"><?php esc_html_e( 'Advanced Options', 'terms-popup-on-user-login' ); ?></a>
            </h2>
            
            <form method="post" action="options.php">
				<?php

				if( $active_tab == 'terms_modal_options' ) {

					?>

						<div class="tg-outer">						
							<?php
								settings_fields( 'tpul_settings_term_modal_options' );
								do_settings_sections( 'tpul_settings_term_modal_options' );
								submit_button();
							?>
						</div>

					<?php
                } elseif( $active_tab == 'reset_users_options' ){
                    ?>
                        <div class="tg-outer">
                            <?php
                                settings_fields( 'tpul_settings_reset_users_options' );
                                do_settings_sections( 'tpul_settings_reset_users_options' );
                                ?>
                                                                
                                <table class="form-table" role="presentation">
                                    <tbody>

                                    <tr>
                                        <th scope="row">Reset all users as if their next login would be their first one.</th>
                                        <td>

                                            <?php $license_key_active = $this->license_key_handler->is_active(); ?>

                                            <?php if ($license_key_active): ?>
                                                <div class="tpul__alowed_box">
                                                    <p class="tpul__license_notify_text"> <?php echo esc_html__( 'You have an active License Key. This feature is avaialble for you.', 'terms-popup-on-user-login' ); ?> </p>
                                            <?php else:?>
                                                <div class="tpul__restricted_box">
                                                    <p class="tpul__license_notify_text"> <?php echo esc_html__( 'This is a Premium Feature. You need a valid license key to activate this feature.', 'terms-popup-on-user-login' ); ?> </p>
                                            <?php endif;?>

                                                <br>
                                                    <p>

                                                    <?php if ($license_key_active): ?>
                                                        <button id="tpul__reset-all" class="tpul_script_button button" href="#" onclick="resetAllUsers(event)">Reset all users</button>
                                                    <?php else:?>
                                                        <button id="tpul__reset-all-1" class="tpul_script_button button" href="#" disabled="disabled" >Reset all users</button>
                                                    <?php endif;?>

                                                        <span class="tpul_reset_button_msg hide"></span>
                                                    </p>
                                                    <p class="description">Use this button if you have updated your Terms and Conditions and would like to force all existing users to accept the updated Terms again.</p>
                                                    <p class="description">After You click the button don't close this window while the script is running.</p>
                                            </div>
                                            <p class="description"><?php echo __( '<b style="color: red;">WARNING! This can not be undone. Running the reset will make the popup show for every user again.</b>', 'terms-popup-on-user-login' ); ?></p>



                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row">System Report</th>
                                        <td>
                                            <div>
                                                PHP Version: 
                                                <?php
                                                   echo phpversion();
                                                ?>
                                            </div> 
                                            <div>
                                                Curl Version: 
                                                <?php
                                                    $values=curl_version();
                                                    echo $values["version"];
                                                ?>
                                            </div>
                                        </td>
                                    </tr>

                                    </tbody>
                                </table>

<!-- 
                                <hr/>
                                <br>
                                <br>
                                <p>Use this button if you would only want to force CURRENT users to accept the updated Terms. BUT Disable the Terms and Conditions for all FUTURE users</p>
                                <p>
                                    <button id="tpul__reset-all" class="tpul_script_button button" href="#" onclick="resetAllUsers(event)"> Disable Popup for FUTURE users</button>
                                    <span class="tpul__msg hide"></span>
                                </p> -->

                        </div>	
                    <?php
				} else {

                    settings_fields( 'tpul_settings_general_options' );
                    do_settings_sections( 'tpul_settings_general_options' );
                    submit_button();

				} // end if/else
                ?>
                </form>



                <hr />
                <div class="tpul__plugin-reviews">
                    <div class="tpul__plugin-reviews-rate">
                        <?php echo __('If you enjoy our plugin, please give it 5 stars on WordPress it helps me a lot:','terms-popup-on-user-login'); ?>
                        <a href="https://wordpress.org/support/plugin/terms-popup-on-user-login/reviews/?filter=5" target="_blank" title="terms popup on user login review">Rate the plugin</a>
                    </div>
                    <div class="tpul__plugin-reviews-support">
                        <?php echo __('If you have any questions on how to use the plugin, feel free to ask them:','terms-popup-on-user-login'); ?>
                        <a href="https://www.lehelmatyus.com/question/question-category/terms-popup-on-user-login-support" title="ask a question" >Support Questions</a>
                    </div>
                    <div class="tpul__plugin-reviews-donate">
                        
                        <?php echo __('Donations play an important role, please consider donating:','terms-popup-on-user-login'); ?>
                        <span class="dashicons dashicons-carrot"></span>
                        <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=EN83B8SEVVLX8&item_name=Help+Support+Terms+Popup+On+User+Login+Options&currency_code=USD&source=url" title="support the plugin" target="_blank" >Donate</a>
                    </div>
                </div>

                
            
            </div><!-- /.wrap -->
        <?php

    }

    /**---------------------------------------------------------------------
     * Helper functions to generate a field
     ---------------------------------------------------------------------*/


    function dropdown_select_field_render(  ) { 

        $options = get_option( 'tpul_settings_general_options' );
        // var_dump($options);
        ?>
        <select name='tpul_settings_general_options[modal_to_show]'>
            <option value='none' <?php selected( $options['modal_to_show'], 'none' ); ?>>Don't show popup</option>
            <option value='terms_and_conditions_modal' <?php selected( $options['modal_to_show'], 'terms_and_conditions_modal' ); ?>>Show popup</option>
            <option value='terms_and_conditions_modal_test' <?php selected( $options['modal_to_show'], 'terms_and_conditions_modal_test' ); ?>>TEST MODE</option>
        </select>
        <p class="description"> 
            <?php echo __( 'When in TEST MODE - Popup will show for every user on every page load. Remember to disable test mode after done testing!', 'terms-popup-on-user-login' ); ?> 
        </p>
        
    <?php
    }

    function  demo_terms_modal_render() {
        ?>
            <a id="tpul__demo_modal_btn" class="button" href="/" onclick="">Click to View Popup</a>
        <?php
    }

    function tplu_license_key_render(  ) { 

        $options = get_option( 'tpul_settings_general_options' );        

        // var_dump($this->license_key_handler);
        $license_key_active = $this->license_key_handler->is_active();

        //var_dump($options);
        //var_dump($this->license_key_handler->get_license_options());
        // var_dump($license_key_handler->get_expiration_date());
        // var_dump($license_key_handler->get_expiration_date_pretty());
        // var_dump($license_key_handler->expiration_in_days());


        ?>
        <p> <?php echo __( 'Purchase a license key to unlock premium features in a matter of minutes. <a target="_blank" href="https://www.lehelmatyus.com/product/terms-popup-on-user-login-license-key">Purchase a License Key Here.</a>', 'terms-popup-on-user-login' ); ?> </p>
        <br/>

            <?php if ($license_key_active) : ?>
                <!-- <div style="border: 1px solid #46b450; padding:10px; background: rgba(70, 180, 80, 0.1)"> -->
                <div class="tpul__alowed_box">
                    <p class="tpul__license_notify_text"><?php echo __( 'Your License Key is active.', 'terms-popup-on-user-login' ); ?> <?php echo __( 'Will expire in', 'terms-popup-on-user-login' ); ?> <b><?php echo $this->license_key_handler->expiration_in_days(); ?></b> <?php echo __( 'days', 'terms-popup-on-user-login' ); ?>. </p>
            <?php else : ?>
                <div class="tpul__alowed_box">
                    <p class="tpul__license_notify_text"><?php echo __( 'Enter License Key to unlock premium features.', 'terms-popup-on-user-login' ); ?></p>
            <?php endif; ?>            
                <br/>
                    <div>
                        <input type='text' class="regular-text" name='tpul_settings_general_options[tplu_license_key]' value='<?php echo $options['tplu_license_key']; ?>'>
                        <?php if ($license_key_active) : ?>
                            <button id="tpul__deactivate-key" class="tpul_script_button button" href="#" onclick="deactivateKey(event)">Deactivate Key</button>
                            <span class="tpul_deactivate_button_loader hide"><img class="load_spinner" src="/wp-includes/images/spinner.gif" /></span>
                            <span class="tpul_deactivate_button_msg hide"></span>
                        <?php else : ?>

                            <button id="tpul__activate-key" class="tpul_script_button button" href="#" onclick="activateKey(event)">Activate Key</button>
                            <span class="tpul_activate_button_loader hide"><img class="load_spinner" src="/wp-includes/images/spinner.gif" /></span>
                            <span class="tpul_activate_button_msg hide"></span>

                        <?php endif; ?>   

                    </div>

            </div>




        <?php
    }


    function terms_modal_title_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_title]' value='<?php echo $options['terms_modal_title']; ?>'>
        <p class="description"> <?php echo __( 'Title of the Modal.', 'terms-popup-on-user-login' ); ?> </p>
        <?php
    }

    function terms_modal_subtitle_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_subtitle]' value='<?php echo $options['terms_modal_subtitle']; ?>'>
        <p class="description"> <?php echo __( 'Text right below the modal title.', 'terms-popup-on-user-login' ); ?> </p>
        <hr/>
        <?php
    }
    
    function terms_modal_agreed_text_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_agreed_text]' value='<?php echo $options['terms_modal_agreed_text']; ?>'>
        <p class="description"> <?php echo __( 'Text that get\'s shown briefly after user clicked the accept button.', 'terms-popup-on-user-login' ); ?> </p>
        <?php
    }
    
    function terms_modal_logout_text_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_logout_text]' value='<?php echo $options['terms_modal_logout_text']; ?>'>
        <p class="description"> <?php echo __( 'Text that get\'s shown briefly before user is logged out.', 'terms-popup-on-user-login' ); ?> </p>
        <hr/>
        <?php
    }

    function terms_modal_accept_button_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_accept_button]' value='<?php echo $options['terms_modal_accept_button']; ?>'>
        <p class="description"> <?php echo __( 'Button text for "Accept" button.', 'terms-popup-on-user-login' ); ?> </p>
        <?php
    }

    function terms_modal_accept_redirect_render(  ) {  
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_accept_redirect]' value='<?php echo $options['terms_modal_accept_redirect']; ?>'>
        <p class="description"> <?php echo esc_html__( 'Can redirect user uppon accpting terms. Does not redirect if left empty, will accept relative url such as "/" or "/about".', 'terms-popup-on-user-login' ); ?> </p>
        <hr/>
        <?php
    }

    function terms_modal_decline_button_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_decline_button]' value='<?php echo $options['terms_modal_decline_button']; ?>'>
        <p class="description"> <?php echo __( 'Button text for "Decline" button.', 'terms-popup-on-user-login' ); ?> </p>
        <?php
    }

    function terms_modal_decline_redirect_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        ?>
        <input type='text' class="regular-text" name='tpul_settings_term_modal_options[terms_modal_decline_redirect]' value='<?php echo $options['terms_modal_decline_redirect']; ?>'>
        <p class="description"> <?php echo __( 'Redirects to home page if left empty, will accept relative url such as "/" or "/about". <br/> For outbound links you must provide protocol such as "http://" in the URLs, example: "http://www.lehelmatyus.com".', 'terms-popup-on-user-login' ); ?> </p>
        <hr/>
        <?php
    }


    function terms_modal_content_render( ){ 
        $options = $this->tpul_settings_term_modal_options;

        printf(
			'<textarea class="large-text" rows="5" name="tpul_settings_term_modal_options[terms_modal_content]" id="terms_modal_content">%s</textarea>',
			isset( $options['terms_modal_content'] ) ? esc_attr( $options['terms_modal_content']) : ''
        );
        
    }

    function dropdown_select_field_pages_render(  ) { 
        
        $general_options = $this->tpul_settings_general_options;
        $options = $this->tpul_settings_term_modal_options;

        $license_key_valid = $this->license_key_handler->is_active();

        // var_dump($general_options);
        // var_dump("is Active?");
        // var_dump($license_key_handler->is_active());

        ?>
        
        <?php if ($license_key_valid): ?>
            <div class="tpul__alowed_box">
                <p class="tpul__license_notify_text"> <?php echo esc_html__( 'You have an active License Key. This feature is avaialble for you.', 'terms-popup-on-user-login' ); ?> </p>
        <?php else:?>
            <div class="tpul__restricted_box">
                <p class="tpul__license_notify_text"> <?php echo esc_html__( 'This is a Premium Feature. You need a valid license key to activate this feature.', 'terms-popup-on-user-login' ); ?> </p>
        <?php endif;?>
            <br/>
            
            <?php $disabled = !$license_key_valid ? "disabled='disabled'" : ""; ?>

            <select name='tpul_settings_term_modal_options[terms_modal_pageid]' <?php echo $disabled ?>>
                <option value='' <?php selected( $options['terms_modal_pageid'], '' ); ?>> - Don't use a page as modal content - </option>
                <?php
                    if( $pages = get_pages() ){
                        foreach( $pages as $page ){
                            echo '<option value="' . $page->ID . '" ' . selected( $page->ID, $options['terms_modal_pageid'] ) . '>' . $page->post_title . '</option>';
                        }
                    }
                ?>
            </select>

            <p> <?php echo esc_html__( 'Select the page that contains your terms and conditions. Will not take effect unless you have active License Key.', 'terms-popup-on-user-login' ); ?> </p>

            <?php // wp_dropdown_pages( array( 'name' => 'russ_options[page_id]', 'selected' => $options['terms_modal_pageid'] ) ); ?>
            
        </div>
            <p class="description"> <?php echo __( 'Selecting a page in this option will take precedence over "Content to show as terms in Popup". The content of the page will be shown instead of the text entered in the textbox above.', 'terms-popup-on-user-login' ); ?> </p>

    <?php
    }

    function terms_modal_disable_for_new_render(  ) { 
        $options = $this->tpul_settings_term_modal_options;
        if( !isset( $options['terms_modal_disable_for_new'] ) ) $options['terms_modal_disable_for_new'] = 0;

        $html = '<input type="checkbox" id="terms_modal_disable_for_new" name="tpul_settings_term_modal_options[terms_modal_disable_for_new]" value="1"' . checked( 1, $options['terms_modal_disable_for_new'], false ) . '/>';
        $html .= '<label for="terms_modal_disable_for_new">Disable Popup for New users.</label>';
    
        echo $html;
    }


}