<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.lehelmatyus.com
 * @since      1.0.0
 *
 * @package    terms_popup_on_user_login
 * @subpackage terms_popup_on_user_login/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    terms_popup_on_user_login
 * @subpackage terms_popup_on_user_login/admin
 * @author     Lehel Matyus <contact@lehelmatyus.com>
 */
class Terms_Popup_On_User_Login_User_Edit {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}


    /**
     * Adds a Checkbox to the user profile edit page for admins to see if the curent user they are looking at accepted or not the terms
     */
    function show_user_profile_accepted_field( $user ) { 

        $user_accepted_terms = get_user_meta($user->ID, 'tpul_user_accepted_terms', 0);
        $user_accepted_check = 0 ;
    
        if ( !empty($user_accepted_terms)){  
            // if 2 then user accepted it.
            if ($user_accepted_terms[0] == 2) {
                $user_accepted_check = 1;
            }
        }
        
        ?>
        <h3><?php _e("Terms Popup on User Login", "terms-popup-on-user-login"); ?></h3>
    
        <table class="form-table">
        <tr>
            <th></th>
            <td>
                <input class="tpul_user_accepted_check" 
                    type="checkbox" 
                    id="tpul_user_accepted_checkbox" 
                    name="tpul_user_accepted_checkbox" 
                    aria-describedby="tpul_user_accepted_checkbox_desc" 
                    value="on" 
                    <?php checked( 1, $user_accepted_check, true ) ?>
                    disabled>
                    <label for="tpul_user_accepted_checkbox"><?php _e("User Accepted Terms at Login ", 'terms-popup-on-user-login' ); ?></label>
                    <br/>
                <p class="description"><?php _e("Checked means this user logged in at some point and accepted user agreement.", 'terms-popup-on-user-login' ); ?></p>
            </td>
        </tr>
        
        </table>
    <?php }

}
