(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

})( jQuery );


/**
 * Reset Users
 */
function resetAllUsers(e){
	e.preventDefault();

	jQuery.ajax({
		url: wpApiSettings.root + 'terms-popup-on-user-login/v1/user/reset-users',
		type: 'POST',
		contentType: 'application/json',
		beforeSend: function (xhr) {
			xhr.setRequestHeader('X-WP-Nonce', wpApiSettings.ftlp_nonce);

			console.log("...");

			jQuery('.tpul_script_button').prop('disabled', true);
			jQuery('.tpul_reset_button_msg').html('Script Running Please Wait...');

		},
		data: JSON.stringify( {
			oo: 'var',
		})
		,
		success: function (response){

		}

	}).done(function (results) {
		console.log('SUCCESS');
		console.log(results);
		jQuery('#tpul__reset-all').prop('disabled', false);
		jQuery('.tpul_reset_button_msg').html('Script Ran Successfully!');
		
	}).fail(function (jqXHR, textStatus, errorThrown) {
		console.log('ERROR');
		console.log(jqXHR);
		console.log(textStatus);
		console.log(errorThrown);
		jQuery('#tpul__reset-all').prop('disabled', false);
		jQuery('.tpul_reset_button_msg').html('Script Failed. Error: ' + errorThrown);
		
	});
}


function activateKey(e){
	e.preventDefault();

	jQuery.ajax({
		url: wpApiSettings.root + 'terms-popup-on-user-login/v1/user/activatekey',
		type: 'POST',
		contentType: 'application/json',
		beforeSend: function (xhr) {
			xhr.setRequestHeader('X-WP-Nonce', wpApiSettings.ftlp_nonce);

			console.log("...");

			jQuery('.tpul_script_button').prop('disabled', true);
			jQuery('.tpul_activate_button_msg, .tpul_activate_button_loader').removeClass('hide');
			jQuery('.tpul_activate_button_msg').html('Script Running Please Wait...');

			console.log(jQuery('[name="tpul_settings_general_options[tplu_license_key]"]').val());

		},
		data: JSON.stringify( {
			'license_key': jQuery('[name="tpul_settings_general_options[tplu_license_key]"]').val()
		})
		,
		success: function (response) {
			// jQuery('[name="tpul_settings_general_options[tplu_license_key]"]').get(0).type = "password";
			jQuery('.tpul_script_button').prop('disabled', false);

		}

	}).done(function (results) {

		console.log('SUCCESS');
		console.log(results);

		jQuery('#tpul__activate-key').type = "password";
		jQuery('#tpul__activate-key').prop('disabled', false);
		jQuery('.tpul_activate_button_loader').addClass('hide');	

		if(results !== null){
			jQuery('.tpul_activate_button_msg').html(results.message);
		}else{
			jQuery('.tpul_activate_button_msg').html("Error: results is null. Please contact support.");
		}

		// if (results.code == 'activated'){
			jQuery('#tpul__activate-key').addClass('hide');
		// }
		
	}).fail(function (jqXHR, textStatus, errorThrown) {

		console.log('ERROR');
		console.log(jqXHR);
		console.log(textStatus);
		console.log('Script Failed. Error: ' + errorThrown);

		jQuery('#tpul__activate-key').prop('disabled', false);
		jQuery('.tpul_activate_button_loader').addClass('hide');
		jQuery('.tpul_activate_button_msg').html('ERROR: ' + jqXHR.responseJSON.message);
		
	});
}


function deactivateKey(e){
	e.preventDefault();

	jQuery.ajax({
		url: wpApiSettings.root + 'terms-popup-on-user-login/v1/user/deactivatekey',
		type: 'POST',
		contentType: 'application/json',
		beforeSend: function (xhr) {
			xhr.setRequestHeader('X-WP-Nonce', wpApiSettings.ftlp_nonce);

			console.log("...");

			jQuery('.tpul_script_button').prop('disabled', true);
			jQuery('.tpul_deactivate_button_msg, .tpul_deactivate_button_loader').removeClass('hide');
			jQuery('.tpul_deactivate_button_msg').html('Script Running Please Wait...');

			console.log(jQuery('[name="tpul_settings_general_options[tplu_license_key]"]').val());

		},
		data: JSON.stringify( {
			'license_key': jQuery('[name="tpul_settings_general_options[tplu_license_key]"]').val()
		})
		,
		success: function (response) {
			// jQuery('[name="tpul_settings_general_options[tplu_license_key]"]').get(0).type = "password";
			jQuery('.tpul_script_button').prop('disabled', false);

		}

	}).done(function (results) {

		console.log('SUCCESS');
		console.log(results);

		jQuery('#tpul__deactivate-key').type = "password";
		jQuery('#tpul__deactivate-key').prop('disabled', false);
		jQuery('.tpul_deactivate_button_loader').addClass('hide');	

		if(results !== null){
			jQuery('.tpul_deactivate_button_msg').html(results.message);
		}else{
			jQuery('.tpul_deactivate_button_msg').html("Error: results is null. Please contact support.");
		}

		// if (results.code == 'deactivated'){
			jQuery('#tpul__deactivate-key').addClass('hide');
		// }
		
	}).fail(function (jqXHR, textStatus, errorThrown) {

		console.log('ERROR');
		console.log(jqXHR);
		console.log(textStatus);
		console.log('Script Failed. Error: ' + errorThrown);

		jQuery('#tpul__deactivate-key').prop('disabled', false);
		jQuery('.tpul_deactivate_button_loader').addClass('hide');
		jQuery('.tpul_deactivate_button_msg').html('ERROR: ' + jqXHR.responseJSON.message);
		
	});
}
