<?php


/**
* @since      1.0.0
* @package    terms_popup_on_user_login
* @subpackage terms_popup_on_user_login/includes
* @author     Lehel Matyus <contact@lehelmatyus.com>
*/
class Terms_Popup_On_User_Login_Key_Handler {

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
    protected $version;

	
	/**
	 * WP options
	 */

	// Labels
	private $option_bundle_label = 'tpul_settings_general_options';
	private $option_key_label = 'tplu_license_key';

	// License valid until etc. need to be saved under a different option bundle lablel because general options get overridden with every form save of general options
	private $option_license_bundle_label = 'tpul_settings_license_option';
	private $option_date_until_label = 'tplu_license_key_valid_until';
	private $option_last_checked_label = 'tplu_license_key_last_checked';

	// to store info
	protected $general_option;

	/**
	 * For Comm with lehelmatyus
	 */
    private $host = 'https://www.lehelmatyus.com';
    private $consumer_key = 'ck_019c9a0410beebb0a16b851bbe1cd4def1c1715d';
	private $consumer_secret = 'cs_6f151c5a6ef6d2251213d42ccc3c1a3fcb364b4d';
		
	// Consumer key
	// ck_019c9a0410beebb0a16b851bbe1cd4def1c1715d

	// Consumer secret
	// cs_6f151c5a6ef6d2251213d42ccc3c1a3fcb364b4d

    public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
        $this->version = $version;

        $this->general_option = get_option( $this->option_bundle_label );
        $this->license_option = get_option( $this->option_license_bundle_label );
    }


    public function is_active() {

        if (empty($this->general_option[$this->option_key_label])) {
			return false;
		}

		if (empty($this->license_option[$this->option_date_until_label])){
			return false;
		}
		
		// If date exits it should be valid format
		if (
				!empty($this->license_option[$this->option_date_until_label]) &&
				!$this->__validate_date($this->license_option[$this->option_date_until_label]))
			{
			return false;
		}

		/**
		 * Validate timestamp
		 */		

		$today = date("Y-m-d H:i:s");

		if (($this->license_option[$this->option_date_until_label]) > $today){
			return true;
		}
			
        return false;
	}


	/**
	 * Activate the key
	 */
	public function activate_key($key = '', $expiration_date = '') {

		if(empty($key)){
			return false;
		}

		if (!empty($expiration_date)){
		}else{
			$expiration_date = '2024-07-01 00:00:00';
		}

		$today = date("Y-m-d H:i:s");

		$this->general_option[$this->option_key_label] = $key;
		$this->license_option[$this->option_date_until_label] = $expiration_date;

		update_option( $this->option_bundle_label, $this->general_option);
		update_option( $this->option_license_bundle_label, $this->license_option);

		return true;
	}

	/**
	 * Flush Key related options
	 */

	public function flush_key_related_info(){

		$this->general_option[$this->option_key_label] = "";
		$this->license_option[$this->option_date_until_label] = "";

		update_option( $this->option_bundle_label, $this->general_option);

	}

	/**
	 * Get Registered Expiration date
	 */
	public function check_if_a_date_is_in_past($date){

		if(!($this->__validate_date($date))){
			return true;
		}

		$today = date("Y-m-d H:i:s");
		if ($today <= $date){
			return false;
		}

		return true;
	}

	/**
	 * Get License options
	 */
	public function get_license_options(){
		return get_option( $this->option_license_bundle_label );
	}


	/**
	 * Get Registered Expiration date
	 */
	public function get_expiration_date(){
		return $this->license_option[$this->option_date_until_label];
	}

	/**
	 * Get Resgistered Expiration date pretty format
	 */
	public function get_expiration_date_pretty(){

		if (!empty($this->get_expiration_date())){
			$orgDate = date_create($this->get_expiration_date());
			$newDate = date_format($orgDate,"d M Y");
			return $newDate;
		}

		return false;
	}

	/**
	 * Get Expiration id Day
	 */
	function expiration_in_days() {

		$differenceFormat = '%a';
		$exp_date = date_create($this->get_expiration_date());
		$today = date_create(date("Y-m-d H:i:s"));
	
		$interval = date_diff($exp_date, $today);
		$diff_days = $interval->format($differenceFormat);

		if($exp_date < $today) {
			$diff_days = -1 * $diff_days;
		}else{
			$diff_days = 1 * $diff_days;
		}

		return $diff_days;
	
	}

	
	/**
	 * Communicate with server to Validate Key
	 */
	public function _comm__validate_key($key_to_activate) {

		if(empty($key_to_activate)) {
			return false;
		}

		$curl = curl_init();

			curl_setopt_array($curl, array (
			CURLOPT_URL => $this->host . '/wp-json/lmfwc/v2/licenses/validate/' . $key_to_activate .'?consumer_key=' . $this->consumer_key . '&consumer_secret=' . $this->consumer_secret,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 0,
			CURLOPT_FOLLOWLOCATION => false,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "GET",
			// CURLOPT_SSL_VERIFYPEER => false   /// REMOVE THIS
		));

		$response = curl_exec($curl);
		$err = curl_error($curl);

		curl_close($curl);

		if ($err) {
			return json_encode(array('message' => 'cURL Error #:' . $err ));
		} else {
			return $response;
		}
	}


	/**
	 * Communicate with server to Activate Key
	 */
	public function _comm__activate_key($key_to_activate) {

		if(empty($key_to_activate)){
			return false;
		}

		$curl = curl_init();

        curl_setopt_array($curl, array(
			CURLOPT_URL => $this->host . '/wp-json/lmfwc/v2/licenses/activate/' . $key_to_activate .'?consumer_key=' . $this->consumer_key . '&consumer_secret=' . $this->consumer_secret,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 0,
			CURLOPT_FOLLOWLOCATION => false,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "GET",
			// CURLOPT_SSL_VERIFYPEER => false   /// REMOVE THIS
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);

        if ($err) {
        	return json_encode(array('message' => 'cURL Error #:' . $err ));
        } else {
        	return $response;
		}
	}

	/**
	 * Communicate with server to Activate Key
	 */
	public function _comm__deactivate_key($key_to_activate) {

		if(empty($key_to_activate)){
			return false;
		}

		$curl = curl_init();

        curl_setopt_array($curl, array(
			CURLOPT_URL => $this->host . '/wp-json/lmfwc/v2/licenses/deactivate/' . $key_to_activate .'?consumer_key=' . $this->consumer_key . '&consumer_secret=' . $this->consumer_secret,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 0,
			CURLOPT_FOLLOWLOCATION => false,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "GET",
			// CURLOPT_SSL_VERIFYPEER => false   /// REMOVE THIS
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);

        if ($err) {
        	return json_encode(array('message' => 'cURL Error #:' . $err ));
        } else {
        	return $response;
		}
	}


	/**
	 * Return Custom Messages Based onevent
	 */
	public function get_message($code){
		
		$message = '';

		switch ($code) {

			case 'activated':
				$message = 'Succesfully activated, be sure to save changes and enjoy your premium features.';
				break;

			case 'deactivated':
				$message = 'Succesfully deactivated, be sure to save changes.';
				break;

			case 'activated2':
				$message = 'Succesfully activated, be sure to save changes and enjoy your premium features..';
				break;
			
			case 'no_key_provided':
				$message = 'No key provided.';
				break;

			case 'key_expired':
				$message = 'Key is expired.';
				break;
				
			case 'key_not_good':
				$message = 'Key provided is not good.';
				break;			
			
			case 'json_parse_error':
				$message = 'Invalid response from lehelmatyus.com. Please contact support.';
				break;

			case 'empty_response':
				$message = 'Empty response from lehelmatyus.com. Please contact support.';
				break;

			case 'unable_to_activate':
				$message = 'Unable to activate.';
				break;

			case 'unable_to_deactivate':
				$message = 'Unable to deactivate.';
				break;
			
			default:
				# code...
				break;
		}

		return $message;

	}


	protected function __validate_date($date, $format = 'Y-m-d H:i:s') {
		// Create the format date
		$d = DateTime::createFromFormat($format, $date);
	
		// Return the comparison    
		return $d && $d->format($format) === $date;
	}


    
}


?>