<?php

/**
 * The modal
 *
 * @link       www.lehelmatyus.com/
 * @since      1.0.0
 *
 * @package    Perfecto_Portfolio
 * @subpackage Perfecto_Portfolio/admin
 */

defined( 'ABSPATH' ) || exit;

require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-terms-popup-on-user-login-keyhandler.php';

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Perfecto_Portfolio
 * @subpackage Perfecto_Portfolio/admin
 * @author     Lehel Matyus <contact@lehelmatyus.com>
 */
class Terms_Popup_On_User_Login_Modal{
    
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
    private $version;
    
    // private $default_modal_type = 'modal-accept-terms';

    // private $modal_type;
    
    /**
	 * Asset Load options
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      Array    $advanced_options    Option saved at the settings page
	 */
	private $generals_options;
	private $terms_options;
	private $license_is_active;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
        $this->version = $version;

        /**
         * Get Options on what to show if anything
         */
        $get_general_options = get_option( 'tpul_settings_general_options' );
		if( false ==  $get_general_options) {
			$this->generals_options = $this->default_tpul_settings_gen_options();
		}else{
			$this->generals_options = $get_general_options;
		}
        
        /**
         * Get Options on what to show if anything
         */
        $get_terms_options = get_option( 'tpul_settings_term_modal_options' );
		if( false ==  $get_terms_options) {
			$this->terms_options = $this->default_tpul_settings_terms_options();
		}else{
			$this->terms_options = $get_terms_options;
        }
        
        $license_key_handler = new Terms_Popup_On_User_Login_Key_Handler($this->plugin_name, $this->version);
        $this->license_is_active = $license_key_handler->is_active();
        
    }

    /**
	 * Provides default values Settings
	 *
	 * @return array
	 */
	public function default_tpul_settings_terms_options() {
		$defaults = array(
			'terms_modal_pageid'	       =>	'',
			'terms_modal_content'	       =>	'',
			'terms_modal_title'	           =>	'Terms and Conditions',
			'terms_modal_subtitle'	       =>	'You must read and scroll down to accept it.',
			'terms_modal_logout_text'	   =>	'You are being Logged out..',
			'terms_modal_agreed_text'	   =>	'You have agreed to terms.',
			'terms_modal_accept_button'	   =>	'Accept',
			'terms_modal_decline_button'   =>	'Decline and Log Out',
			'terms_modal_accept_redirect'  =>	'',
			'terms_modal_decline_redirect' =>	'/',
			'terms_modal_disable_for_new' =>	0,
		);
		return $defaults;
	}
    /**
	 * Provides default values Settings
	 *
	 * @return array
	 */
	public function default_tpul_settings_gen_options() {
		$defaults = array(
			'modal_to_show'	=>	'none',
		);
		return $defaults;
	}
    
    
    /**
	 * Adds modal to page
	 *
	 * @since    1.0.0
	 */
	public function add_modal_to_footer() {

		if( is_user_logged_in()) {
            

            switch ($this->generals_options['modal_to_show']) {

                case 'modal-first-welcome':
                    
                    $this->insert_modal_first();
                    break;
                
                case 'terms_and_conditions_modal':
                case 'terms_and_conditions_modal_test':
            
                    $this->insert_modal_must_accept_terms();
                    break;
                
                default:
                    # code...
                    break;
            }

        }
    }

    /**
     * Modal Builds
     */

	public function insert_modal_first() {

        echo '<div class="modal micromodal-slide" id="modal-first-welcome" aria-hidden="true">';
        echo '<div class="modal__overlay" tabindex="-1" data-micromodal-close>';
            echo '<div class="modal__container" role="dialog" aria-modal="true" aria-labelledby="modal-first-welcome-title">';
            echo '<header class="modal__header">';
                echo '<h2 class="modal__title" id="modal-first-welcome-title">';
                echo 'Micromodal';
                echo '</h2>';
                echo '<button class="modal__close" aria-label="Close modal" data-micromodal-close></button>';
            echo '</header>';
            echo '<main class="modal__content" id="modal-first-welcome-content">';
                echo '<p>';
                echo 'Try hitting the <code>tab</code> key and notice how the focus stays within the modal itself. Also, <code>esc</code> to close modal.';
                echo '</p>';
            echo '</main>';
            echo '<footer class="modal__footer">';
                echo '<button class="modal__btn modal__btn-primary">Continue</button>';
                echo '<button class="modal__btn" data-micromodal-close aria-label="Close this dialog window">Close</button>';
            echo '</footer>';
            echo '</div>';
        echo '</div>';
        echo '</div>';

    }

    public function insert_modal_must_accept_terms() {


        echo '<div class="ftlp_modal modal micromodal-slide" id="modal-accept-terms" aria-hidden="true">';
        echo '<div class="modal__overlay" tabindex="-1" >';
            echo '<div class="modal__container" role="dialog" aria-modal="true" aria-labelledby="modal-accept-terms-title">';

            if (!empty(($this->terms_options['terms_modal_title']))) {
                echo '<header class="modal__header">';
                    echo '<h2 class="modal__title" id="modal-accept-terms-title">';
                        echo $this->terms_options['terms_modal_title'];
                    echo '</h2>';
                echo '</header>';
            }

            echo '<main class="modal__content" id="modal-accept-terms-content">';
            
                if (!empty(($this->terms_options['terms_modal_subtitle']))) {
                    echo '<p class="modal__subtitle_wrapper">';
                        echo $this->terms_options['terms_modal_subtitle'];
                    echo '</p>';
                }

                echo '<div class="modal__terms_wrapper">';

                    echo '<div class="modal__terms__inner">';

                        if ((!empty($this->terms_options['terms_modal_pageid'])) && $this->license_is_active ){
                            $post_id = $this->terms_options['terms_modal_pageid'];
                            $post_content = get_post($post_id);
                            $content = $post_content->post_content;
                            echo apply_filters('the_content',$content);
                        }elseif(!empty($this->terms_options['terms_modal_content'])){
                            $content = $this->terms_options['terms_modal_content'];
                            echo apply_filters('the_content',$content);
                        }

                    echo '</div>';

                echo '</div>';

                echo '<div class="modal__logginout_wrapper hide">';
                    if (!empty(($this->terms_options['terms_modal_logout_text']))) {
                        echo $this->terms_options['terms_modal_logout_text'];
                    }
                echo '</div>';

                echo '<div class="modal__accepting_wrapper hide">';
                    if (!empty(($this->terms_options['terms_modal_agreed_text']))) {
                        echo $this->terms_options['terms_modal_agreed_text'];
                    }
                echo '</div>';

                echo '<div class="modal__loader_wrapper hide">';
                    echo '<div class="ftlp_loader"></div>';
                echo '</div>';

            echo '</main>';

            echo '<footer class="modal__footer">';
                echo '<button class="modal__btn modal__close" data-micromodal-close1 aria-label="Close this dialog window">' . $this->terms_options['terms_modal_decline_button'] . '</button>';
                echo '<button class="modal__btn modal_accept modal__btn_accept modal__btn-primary disabled" disabled >' . $this->terms_options['terms_modal_accept_button'] . '</button>';
            echo '</footer>';

            echo '</div>';
        echo '</div>';
        echo '</div>';

    }

    // function trow_popup($login) {
        
    //     // $user = get_user_by('login', $login);
    //     // $user_id = $user->ID;

    //     // $ever_logged_in = get_user_meta($user_id, 'tpul_user_accepted_terms', 0);

    //     // if ( empty($ever_logged_in) || $ever_logged_in[0] == 0 || $ever_logged_in[0] == 1){
    //     //     /**
    //     //      * empty - OK: flag was never set
    //     //      * 0 - OK: flag was set for testing
    //     //      * 1 - OK: flag was set and this is first time he logs in
    //     //      * 2 - No Go: logged in already at some point
    //     //      * 
    //     //      * do something for first login.. e.g., send a custom email
    //     //      * 
    //     //      */                        
    //     // }
    // }

    function add_slug_body_class( $classes ) {

        if( is_user_logged_in()) {

            /**
             * Check If Test mode
             */
            if ( $this->generals_options['modal_to_show'] == 'terms_and_conditions_modal_test'){
                $classes[] = $this->_get_body_class_to_add();
            }else{


                        $user_id = get_current_user_id();

                        // Get user accepted terms field default to 0, if they have never been set
                        $ever_logged_in = get_user_meta($user_id, 'tpul_user_accepted_terms', 0);

                        if (!empty($this->terms_options['terms_modal_disable_for_new'])){
                            // 1. Admin wants to show popup for OLD users

                            if ( !empty($ever_logged_in)){     
                                if ( $ever_logged_in[0] == 1){                
                                    // Only show for the ones that were marked by the reset.
                                    $classes[] = $this->_get_body_class_to_add();
                                }
                            }

                        }else{
                            // 2. Admin wants to show it for new users as well

                            if ( empty($ever_logged_in) || $ever_logged_in[0] == 0 || $ever_logged_in[0] == 1){                
                                // Show for the ones that were rest with "1" but also to ones that have never been reset "0" or empty
                                $classes[] = $this->_get_body_class_to_add();
                            }
                        }
            }
            
            

        }
        return $classes;
    }


    /**
     * Returns the class-name we need to put on the body;
     */

    function _get_body_class_to_add(){

        switch ($this->generals_options['modal_to_show']) {

            case 'modal-first-welcome':
                
                    return 'terms-popup-on-user-login-modal';

                break;
            
            case 'terms_and_conditions_modal':
        
                    return 'terms-popup-on-user-login-accept-terms';

                break;

            case 'terms_and_conditions_modal_test':
        
                    return 'terms-popup-on-user-login-accept-terms-testmode';

                break;
            
            default:
                # code...
                break;
        }

        return 'terms-popup-on-user-login-none';

    }


}