(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */


	/**
	 * Ajax Calls ---------------------------------------------------------------------------
	 */

	/**
	 * Handle Logout
	 */
	function logoutUser (e){
		$.ajax({
			url: wpApiSettings.root + 'terms-popup-on-user-login/v1/user/logout-user',
			type: 'POST',
			contentType: 'application/json',
			beforeSend: function (xhr) {
				xhr.setRequestHeader('X-WP-Nonce', wpApiSettings.ftlp_nonce);

				$('.modal__subtitle_wrapper').addClass("hide");
				$('.modal__terms_wrapper').addClass("hide");
				$('.modal__btn').addClass("hide");

				$('.modal__logginout_wrapper').removeClass("hide");
				$('.modal__loader_wrapper').removeClass("hide");

				console.log("...");

			},
			data: JSON.stringify( {
				oo: 'var',
			})
			,
			success: function (response){
			}

		}).done(function (results) {
            console.log('SUCCESS');
			console.log(results);
			if (results){
				if (results.data.redirect){
					window.location.replace(results.data.redirect);
				}else{
					window.location.replace("/");
				}
			}
			
        }).fail(function (jqXHR, textStatus, errorThrown) {
            console.log('ERROR');
            console.log(jqXHR);
            console.log(textStatus);
			console.log(errorThrown);
			document.location.href = "/";
        });

	}

	/**
	 * Handle Accepted Terms
	 */

	function acceptTermsUser (e){
		$.ajax({
			url: wpApiSettings.root + 'terms-popup-on-user-login/v1/user/accept-terms',
			type: 'POST',
			contentType: 'application/json',
			beforeSend: function (xhr) {
				xhr.setRequestHeader('X-WP-Nonce', wpApiSettings.ftlp_nonce);

				$('.modal__subtitle_wrapper').addClass("hide");
				$('.modal__terms_wrapper').addClass("hide");
				$('.modal__btn').addClass("hide");

				$('.modal__accepting_wrapper').removeClass("hide");
				$('.modal__loader_wrapper').removeClass("hide");

			},
			data: JSON.stringify( {
				oo: 'var',
			})
			,
			success: function (response){
			}

		}).done(function (results) {
            console.log('SUCCESS');
			console.log(results);
			console.log(results.data.redirect);
			if (results){					
				
				console.log(results);

				if (results.data.redirect){
					window.location.replace(results.data.redirect);
				}else{
					if (results.data.accepted){
						MicroModal.close();
					}
				}
				
			}
			
        }).fail(function (jqXHR, textStatus, errorThrown) {
            console.log('ERROR');
            console.log(jqXHR);
            console.log(textStatus);
			console.log(errorThrown);
			document.location.href = "/";
        });

	}


	/**
	 * Setup and Call Modal ---------------------------------------------------------------------------
	 */

	$(function() {

		// https://micromodal.now.sh/

		/**
		 * Setup Modal To Simple First time notification
		 */
		// if($('body.terms-popup-on-user-login-modal').length){

		// 	MicroModal.init({
		// 		onShow: modal => console.info(`${modal.id} is shown`), // [1]
		// 		onClose: modal => console.info(`${modal.id} is hidden`), // [2]
		// 		openTrigger: 'data-custom-open', // [3]
		// 		closeTrigger: 'data-custom-close', // [4]
		// 		openClass: 'is-open', // [5]
		// 		disableScroll: true, // [6]
		// 		disableFocus: false, // [7]
		// 		awaitOpenAnimation: false, // [8]
		// 		awaitCloseAnimation: false, // [9]
		// 		debugMode: false // [10]
		// 	});
		
		// 	MicroModal.show('modal-first-welcome');
		// }

		/**
		 * Show Accept Terms
		 */
		if($('body.terms-popup-on-user-login-accept-terms').length){

			MicroModal.init({
				onShow: modal => console.info(`${modal.id} is shown`), // [1]
				onClose: modal => console.info(`${modal.id} is hidden`), // [2]
				openTrigger: 'data-custom-open', // [3]
				closeTrigger: 'data-custom-close', // [4]
				openClass: 'is-open', // [5]
				disableScroll: true, // [6]
				disableFocus: true, // [7]
				awaitOpenAnimation: false, // [8]
				awaitCloseAnimation: false, // [9]
				debugMode: false // [10]
			});
		
			/**
			 * Show Modal
			 */
			MicroModal.show('modal-accept-terms');
		}

		/**
		 * Test Mode
		 */
		if($('body.terms-popup-on-user-login-accept-terms-testmode').length){

			MicroModal.init({
				onShow: modal => console.info(`${modal.id} is shown`), // [1]
				onClose: modal => console.info(`${modal.id} is hidden`), // [2]
				openTrigger: 'data-custom-open', // [3]
				closeTrigger: 'data-custom-close', // [4]
				openClass: 'is-open', // [5]
				disableScroll: true, // [6]
				disableFocus: true, // [7]
				awaitOpenAnimation: false, // [8]
				awaitCloseAnimation: false, // [9]
				debugMode: false // [10]
			});
		
			/**
			 * Show Modal
			 */
			MicroModal.show('modal-accept-terms');
		}

		/**
		 * Disable Accept button until User Scrolls down if content surpasses container and scroll is available
		 */
		
		if ($('.modal__terms__inner').height() > 577) {

			$('.modal__terms_wrapper').scroll(function () {
				if ($(this).scrollTop() == $(this)[0].scrollHeight - $(this).height()) {
					$('.modal__btn-primary').removeAttr('disabled');
					$('.modal__btn-primary').removeClass('disabled');
				}
			});
		}else{
			$('.modal__btn-primary').removeAttr('disabled');
			$('.modal__btn-primary').removeClass('disabled');
		}


		/**
		 * Decline button was clicked
		 */
		$('.modal__close').click(function () {
			if($('body.terms-popup-on-user-login-accept-terms-testmode').length){
				
				/**
				 * Test mode: ON
				 * Simulate Ajax Call to decline terms
				 */

				$('.modal__subtitle_wrapper').addClass("hide");
				$('.modal__terms_wrapper').addClass("hide");
				$('.modal__btn').addClass("hide");

				$('.modal__logginout_wrapper').removeClass("hide");
				$('.modal__loader_wrapper').removeClass("hide");

				setTimeout(function(){ 
					MicroModal.close();
					alert("You would now be logged out. -- TEST MODE is still ON. Remember to turn it OFF at Settings > Terms Popup on User Login.");
				}, 3000);

			}else{
				logoutUser();
			}
		});


		/**
		 * Accept button was clicked
		 */
		$('.modal_accept').click(function () {

			if($('body.terms-popup-on-user-login-accept-terms-testmode').length){

				/**
				 * Test mode: ON
				 * Simulate Ajax Call to accept terms
				 */

				$('.modal__subtitle_wrapper').addClass("hide");
				$('.modal__terms_wrapper').addClass("hide");
				$('.modal__btn').addClass("hide");

				$('.modal__accepting_wrapper').removeClass("hide");
				$('.modal__loader_wrapper').removeClass("hide");

				setTimeout(function(){ 
					MicroModal.close();
					alert("TEST MODE is still ON. Remember to Turn Test mode OFF at Settings > Terms Popup on User Login.");
				}, 3000);
				
			}else{

				/**
				 * Live Mode
				 * Register that User accepted the terms.
				 */
				acceptTermsUser();
			}
		});


	});	


})( jQuery );
